@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class HelloworldDjangoConfig(AppConfig):
-    name = 'helloworld_django'
+    name = 'finitelycomputable.helloworld_django'
